%global noupdatechecks_version 20131026svn14849

Name:           findbugs
Version:        2.0.2
Release:        2%{?dist}
Summary:        Find bugs in Java code

Group:          Development/Languages
License:        LGPLv2+
URL:            http://findbugs.sourceforge.net/
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}-source.zip
Source1:        findbugs-ant
Source2:        findbugs-tools-README

# Versions will be fixed in a patch
Source3:        http://search.maven.org/remotecontent?filepath=com/google/code/findbugs/findbugs/2.0.1/findbugs-2.0.1.pom
Source4:        http://repo1.maven.org/maven2/net/sourceforge/findbugs/annotations/1.3.2/annotations-1.3.2.pom

# This archive contains the source for the noUpdateChecks plugin.
# It was created with:
#   $ svn export http://findbugs.googlecode.com/svn/trunk/plugins/noUpdateChecks -r 14849 noUpdateChecks-plugin-20131026svn14849
#   $ tar -zcf noUpdateChecks-plugin-20131026svn14849.tgz noUpdateChecks-plugin-20131026svn14849
Source5:        noUpdateChecks-plugin-%{noupdatechecks_version}.tgz

# This patch has not been submitted upstream, as it contains Fedora-specific
# changes.  It looks in /usr/share/java for jar files at compile time, instead
# of in findbugs' lib directory.
Patch0:         findbugs-build.patch

# Fedora-specific patch:
#  - Remove Class-Path entry from findbugs.jar manifest; use build-classpath
#    instead (#575632)
#  - Simplify shell fragment that determines findbugs_home (also fixes #848612)
Patch1:         findbugs-fedora.patch

# Patch to fix bug #1157 (https://sourceforge.net/p/findbugs/bugs/1157/)
Patch2:         findbugs-bug-1157.patch

BuildArch:      noarch

BuildRequires:  findbugs-bcel
BuildRequires:  ant
BuildRequires:  docbook-style-xsl
BuildRequires:  apache-commons-lang
BuildRequires:  java-devel >= 1:1.6.0
BuildRequires:  jaxen
BuildRequires:  jcip-annotations
BuildRequires:  jdepend
BuildRequires:  jFormatString
BuildRequires:  jpackage-utils
BuildRequires:  jsr-305
BuildRequires:  junit4
BuildRequires:  objectweb-asm
BuildRequires:  perl
BuildRequires:  tex(latex)
BuildRequires:  texlive-preprint
Requires:       findbugs-bcel
Requires:       apache-commons-lang
Requires:       java >= 1:1.6.0
Requires:       jaxen
Requires:       jcip-annotations
Requires:       jFormatString
Requires:       jpackage-utils
Requires:       jsr-305
Requires:       junit4
Requires:       objectweb-asm

%description
Findbugs is a program which uses static analysis to look for bugs in Java code.
It can check for null pointer exceptions, multithreaded code errors, and other
bugs.

%package -n ant-findbugs
Group:          Development/Build Tools
Summary:        Ant task for findbugs
Requires:       %{name} = %{version}-%{release}
Requires:       ant

%description -n ant-findbugs
This package defines an ant task for findbugs for easy integration of findbugs
into your ant-controlled project.

%package javadoc
Group:          Development/Documentation
Summary:        Javadoc documentation for findbugs
Requires:       %{name} = %{version}-%{release}

%description javadoc
Javadoc documentation for findbugs.

%package tools
Group:          Development/Languages
Summary:        Addon tools for findbugs
Requires:       %{name} = %{version}-%{release}
Requires:       junit4

%description tools
This package contains additional tools for use with findbugs.  See
README.fedora for more information.

%prep
%setup -q
%setup -a 5
%patch0 -p1
%patch1 -p1
%patch2 -p1

cp -p %{SOURCE3} findbugs.pom
sed -i 's/2\.0\.1/2\.0\.2/g' findbugs.pom
cp -p %{SOURCE4} annotations.pom
sed -i 's/1\.3\.2/2\.0\.2/g' annotations.pom

cp -p %{SOURCE2} README.fedora

# Make sure we don't accidentally use any existing JAR files
rm -f lib/*.jar

# Get rid of code for Mac OS X that depends on a jar from Apple
rm -f src/gui/edu/umd/cs/findbugs/gui2/OSXAdapter.java

# Turn on the executable bits for some auxiliary scripts
chmod a+x etc/summarizeBugs etc/diffBugSummaries design/architecture/mkdep.pl

%build
# Build the class files
ant

# Build the javadocs
ant apiJavadoc

# Build the architecture PDF
pushd design/architecture
make depend
make
popd

# Package up the tools
pushd build/classes
jar cf ../../lib/findbugs-tools.jar edu/umd/cs/findbugs/tools
popd

# Build the noUpdateChecks plugin
pushd noUpdateChecks-plugin-%{noupdatechecks_version}
ant plugin-jar
popd

%install
# Install the jars
mkdir -p $RPM_BUILD_ROOT%{_javadir}
cp -p lib/annotations.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-annotations.jar
cp -p lib/%{name}-tools.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-tools.jar
cp -p lib/%{name}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}.jar

# Install the ant task
mkdir -p $RPM_BUILD_ROOT%{_javadir}/ant
cp -p lib/%{name}-ant.jar $RPM_BUILD_ROOT%{_javadir}/ant/ant-%{name}.jar
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/ant.d
cp -p %{SOURCE1} $RPM_BUILD_ROOT%{_sysconfdir}/ant.d/%{name}

# Install the javadocs
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}
cp -a apiJavaDoc $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}

# Install the scripts
mkdir -p $RPM_BUILD_ROOT%{_bindir}
for f in $(find bin -maxdepth 1 -type f \! -name '*.bat' \! -name '*.ico'); do
  cp -p $f $RPM_BUILD_ROOT%{_bindir}
done

# Install the shared files
mkdir -p $RPM_BUILD_ROOT%{_datadir}/%{name}
cp -a etc plugin $RPM_BUILD_ROOT%{_datadir}/%{name}

# Install the noUpdateChecks plugin
cp -p noUpdateChecks-plugin-%{noupdatechecks_version}/build/noUpdateChecks.jar $RPM_BUILD_ROOT%{_datadir}/%{name}/plugin

# Remove now unnecessary build-only manual files so %%doc doesn't get them
rm -f doc/manual*.xml doc/manual*.xsl

# Install poms
mkdir -p $RPM_BUILD_ROOT%{_mavenpomdir}
cp findbugs.pom $RPM_BUILD_ROOT%{_mavenpomdir}/JPP-%{name}.pom
cp annotations.pom $RPM_BUILD_ROOT%{_mavenpomdir}/JPP-%{name}-annotations.pom

# Add depmaps
%add_maven_depmap JPP-%{name}.pom %{name}.jar
%add_maven_depmap JPP-%{name}-annotations.pom %{name}-annotations.jar

%files
%doc licenses/LICENSE.txt design/DecouplingFromBCEL.txt design/VisitingAndCaching.txt
%doc README.txt "design/eclipse findbugs plugin features.sxw"
%doc design/architecture/architecture.pdf doc
%{_bindir}/*
%{_datadir}/%{name}
%{_javadir}/findbugs-annotations.jar
%{_javadir}/findbugs.jar
%{_mavenpomdir}/*
%{_mavendepmapfragdir}/*

%files -n ant-findbugs
%doc licenses/LICENSE.txt
%{_javadir}/ant/ant-findbugs.jar
%config(noreplace) %{_sysconfdir}/ant.d/%{name}

%files javadoc
%{_javadocdir}/*

%files tools
%doc licenses/LICENSE.txt README.fedora
%{_javadir}/findbugs-tools.jar

%changelog
* Sat Oct 26 2013 Richard Fearn <richardfearn@gmail.com> - 2.0.2-2
- Add noUpdateChecks plugin, and fix bug #1157

* Wed Sep 11 2013 Richard Fearn <richardfearn@gmail.com> - 2.0.2-1
- Update to 2.0.2

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.9-17
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jul 17 2013 Petr Pisar <ppisar@redhat.com> - 1.3.9-16
- Perl 5.18 rebuild

* Sun Feb 24 2013 Richard Fearn <richardfearn@gmail.com> - 1.3.9-15
- Properly quote "eclipse findbugs plugin features.sxw" filename

* Sun Feb 24 2013 Richard Fearn <richardfearn@gmail.com> - 1.3.9-14
- Add BR for texlive-preprint, needed to build architecture PDF

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.9-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Aug 16 2012 Richard Fearn <richardfearn@gmail.com> - 1.3.9-12
- Allow FindBugs launcher scripts to be run from /bin or /usr/bin (#848612)

* Sat Jul 28 2012 Richard Fearn <richardfearn@gmail.com> - 1.3.9-11
- Remove Class-Path entry from findbugs.jar manifest (#575632); also remove
  Main-Class entry

* Sat Jul 28 2012 Richard Fearn <richardfearn@gmail.com> - 1.3.9-10
- Use Fedora JAR filenames (fixes FTBFS)

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.9-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Mar 14 2012 Marek Goldmann <mgoldman@redhat.com> 1.3.9-8
- Added POMS (RHBZ#803352)

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.9-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Thu Aug 25 2011 Alexander Kurtakov <akurtako@redhat.com> 1.3.9-6
- Adapt for building/running with openjdk 7.
- Remove not needed parts.

* Mon Jun 27 2011 Richard Fearn <richardfearn@gmail.com> - 1.3.9-5
- Rebuild for ASM 3.3

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.9-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Jun  2 2010 Richard Fearn <richardfearn@gmail.com> - 1.3.9-3
- Rebuild for ASM 3.2

* Thu Jan 14 2010 Jerry James <loganjerry@gmail.com> - 1.3.9-2
- Rebuild for jdepend 2.9.1 (bz 555476)

* Tue Aug 25 2009 Jerry James <loganjerry@gmail.com> - 1.3.9-1
- Update to 1.3.9

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Mar 17 2009 Jerry James <loganjerry@gmail.com> - 1.3.8-1
- Update to 1.3.8

* Tue Mar 10 2009 Jerry James <loganjerry@gmail.com> - 1.3.7-6
- Force building with OpenJDK; see GCJ note at the top of the spec file

* Tue Mar 10 2009 Jerry James <loganjerry@gmail.com> - 1.3.7-5
- Add missing ant-nodeps BR

* Fri Mar  6 2009 Jerry James <loganjerry@gmail.com> - 1.3.7-4
- Add README.fedora to the -tools package

* Thu Mar  5 2009 Jerry James <loganjerry@gmail.com> - 1.3.7-3
- Minor spec file cleanups from review

* Tue Feb 10 2009 Jerry James <loganjerry@gmail.com> - 1.3.7-2
- Rebuild for dependencies

* Fri Jan  2 2009 Jerry James <loganjerry@gmail.com> - 1.3.7-1
- Update to 1.3.7

* Tue Dec  9 2008 Jerry James <loganjerry@gmail.com> - 1.3.6-1
- Update to 1.3.6

* Fri Sep 19 2008 Jerry James <loganjerry@gmail.com> - 1.3.5-1
- Initial RPM
